@@ -4,30 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class CapacityManagerDataExportStatus
-  {
-    NOT_SET,
-    pending,
-    in_progress,
-    delivered,
-    failed
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class CapacityManagerDataExportStatus { NOT_SET, pending, in_progress, delivered, failed };
 
-namespace CapacityManagerDataExportStatusMapper
-{
+namespace CapacityManagerDataExportStatusMapper {
 AWS_EC2_API CapacityManagerDataExportStatus GetCapacityManagerDataExportStatusForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForCapacityManagerDataExportStatus(CapacityManagerDataExportStatus value);
-} // namespace CapacityManagerDataExportStatusMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace CapacityManagerDataExportStatusMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
