@@ -4,29 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class DefaultInstanceMetadataEndpointState
-  {
-    NOT_SET,
-    disabled,
-    enabled,
-    no_preference
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class DefaultInstanceMetadataEndpointState { NOT_SET, disabled, enabled, no_preference };
 
-namespace DefaultInstanceMetadataEndpointStateMapper
-{
+namespace DefaultInstanceMetadataEndpointStateMapper {
 AWS_EC2_API DefaultInstanceMetadataEndpointState GetDefaultInstanceMetadataEndpointStateForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForDefaultInstanceMetadataEndpointState(DefaultInstanceMetadataEndpointState value);
-} // namespace DefaultInstanceMetadataEndpointStateMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace DefaultInstanceMetadataEndpointStateMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
