@@ -4,30 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class FpgaImageAttributeName
-  {
-    NOT_SET,
-    description,
-    name,
-    loadPermission,
-    productCodes
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class FpgaImageAttributeName { NOT_SET, description, name, loadPermission, productCodes };
 
-namespace FpgaImageAttributeNameMapper
-{
+namespace FpgaImageAttributeNameMapper {
 AWS_EC2_API FpgaImageAttributeName GetFpgaImageAttributeNameForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForFpgaImageAttributeName(FpgaImageAttributeName value);
-} // namespace FpgaImageAttributeNameMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace FpgaImageAttributeNameMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
