@@ -4,27 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class IpamPoolSourceResourceType
-  {
-    NOT_SET,
-    vpc
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class IpamPoolSourceResourceType { NOT_SET, vpc };
 
-namespace IpamPoolSourceResourceTypeMapper
-{
+namespace IpamPoolSourceResourceTypeMapper {
 AWS_EC2_API IpamPoolSourceResourceType GetIpamPoolSourceResourceTypeForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForIpamPoolSourceResourceType(IpamPoolSourceResourceType value);
-} // namespace IpamPoolSourceResourceTypeMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace IpamPoolSourceResourceTypeMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
