@@ -4,29 +4,19 @@
  */
 
 #pragma once
-#include <aws/ec2/EC2_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/ec2/EC2_EXPORTS.h>
 
-namespace Aws
-{
-namespace EC2
-{
-namespace Model
-{
-  enum class UsageClassType
-  {
-    NOT_SET,
-    spot,
-    on_demand,
-    capacity_block
-  };
+namespace Aws {
+namespace EC2 {
+namespace Model {
+enum class UsageClassType { NOT_SET, spot, on_demand, capacity_block };
 
-namespace UsageClassTypeMapper
-{
+namespace UsageClassTypeMapper {
 AWS_EC2_API UsageClassType GetUsageClassTypeForName(const Aws::String& name);
 
 AWS_EC2_API Aws::String GetNameForUsageClassType(UsageClassType value);
-} // namespace UsageClassTypeMapper
-} // namespace Model
-} // namespace EC2
-} // namespace Aws
+}  // namespace UsageClassTypeMapper
+}  // namespace Model
+}  // namespace EC2
+}  // namespace Aws
